tests.test_traversal module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_traversal module

## tests.test_traversal

Tests traversing the sysfs hierarchy.

class `tests.test_traversal.` `TestTraversal`

  Bases: `object`

  An empty test class which is always skipped.

  `pytestmark` = [<MarkDecorator 'skipif' {'args': (True,), 'kwargs': {'reason': u'no slaves or holders data for tests'}}>]
  `test_dummy`()

    A dummy test, for which pytest can show a skip message.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »